@@ -88,42 +88,6 @@ gdm_get_pwent_for_name (const char     *name,
         return (pwent != NULL);
 }
 
-gboolean
-gdm_get_pwent_for_uid (uid_t           uid,
-                       struct passwd **pwentp)
-{
-        struct passwd *pwent;
-
-        do {
-                errno = 0;
-                pwent = getpwuid (uid);
-        } while (pwent == NULL && errno == EINTR);
-
-        if (pwentp != NULL) {
-                *pwentp = pwent;
-        }
-
-        return (pwent != NULL);
-}
-
-gboolean
-gdm_get_grent_for_name (const char    *name,
-                        struct group **grentp)
-{
-        struct group *grent;
-
-        do {
-                errno = 0;
-                grent = getgrnam (name);
-        } while (grent == NULL && errno == EINTR);
-
-        if (grentp != NULL) {
-                *grentp = grent;
-        }
-
-        return (grent != NULL);
-}
-
 static gboolean
 gdm_get_grent_for_gid (gint           gid,
                        struct group **grentp)
@@ -357,10 +321,8 @@ gdm_generate_random_bytes (gsize    size,
         close (fd);
         return bytes;
 }
-
 static gboolean
 create_transient_display (GDBusConnection *connection,
-                          GCancellable    *cancellable,
                           GError         **error)
 {
         GError *local_error = NULL;
@@ -376,10 +338,10 @@ create_transient_display (GDBusConnection *connection,
                                              G_VARIANT_TYPE ("(o)"),
                                              G_DBUS_CALL_FLAGS_NONE,
                                              -1,
-                                             cancellable, &local_error);
+                                             NULL, &local_error);
         if (reply == NULL) {
                 g_warning ("Unable to create transient display: %s", local_error->message);
-                g_propagate_prefixed_error (error, local_error, _("Unable to create transient display: "));
+                g_propagate_error (error, local_error);
                 return FALSE;
         }
 
@@ -392,17 +354,12 @@ create_transient_display (GDBusConnection *connection,
 
 gboolean
 gdm_activate_session_by_id (GDBusConnection *connection,
-                            GCancellable    *cancellable,
                             const char      *seat_id,
                             const char      *session_id)
 {
         GError *local_error = NULL;
         GVariant *reply;
 
-        g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), FALSE);
-        g_return_val_if_fail (seat_id != NULL, FALSE);
-        g_return_val_if_fail (session_id != NULL, FALSE);
-
         reply = g_dbus_connection_call_sync (connection,
                                              "org.freedesktop.login1",
                                              "/org/freedesktop/login1",
@@ -412,7 +369,7 @@ gdm_activate_session_by_id (GDBusConnection *connection,
                                              NULL,
                                              G_DBUS_CALL_FLAGS_NONE,
                                              -1,
-                                             cancellable, &local_error);
+                                             NULL, &local_error);
         if (reply == NULL) {
                 g_warning ("Unable to activate session: %s", local_error->message);
                 g_error_free (local_error);
@@ -424,38 +381,6 @@ gdm_activate_session_by_id (GDBusConnection *connection,
         return TRUE;
 }
 
-gboolean
-gdm_terminate_session_by_id (GDBusConnection *connection,
-                             GCancellable    *cancellable,
-                             const char      *session_id)
-{
-        GError *local_error = NULL;
-        GVariant *reply;
-
-        g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), FALSE);
-        g_return_val_if_fail (session_id != NULL, FALSE);
-
-        reply = g_dbus_connection_call_sync (connection,
-                                             "org.freedesktop.login1",
-                                             "/org/freedesktop/login1",
-                                             "org.freedesktop.login1.Manager",
-                                             "TerminateSession",
-                                             g_variant_new ("(s)", session_id),
-                                             NULL,
-                                             G_DBUS_CALL_FLAGS_NONE,
-                                             -1,
-                                             cancellable, &local_error);
-        if (reply == NULL) {
-                g_warning ("Unable to terminate session: %s", local_error->message);
-                g_error_free (local_error);
-                return FALSE;
-        }
-
-        g_variant_unref (reply);
-
-        return TRUE;
-}
-
 gboolean
 gdm_get_login_window_session_id (const char  *seat_id,
                                  char       **session_id)
@@ -463,8 +388,9 @@ gdm_get_login_window_session_id (const char  *seat_id,
         gboolean   ret;
         int        res, i;
         char     **sessions;
-
-        g_return_val_if_fail (session_id != NULL, FALSE);
+        char      *service_id;
+        char      *service_class;
+        char      *state;
 
         res = sd_seat_get_sessions (seat_id, &sessions, NULL, NULL);
         if (res < 0) {
@@ -479,9 +405,6 @@ gdm_get_login_window_session_id (const char  *seat_id,
         }
 
         for (i = 0; sessions[i]; i ++) {
-                char *service_id = NULL;
-                char *service_class = NULL;
-                char *state = NULL;
 
                 res = sd_session_get_class (sessions[i], &service_class);
                 if (res < 0) {
@@ -500,8 +423,8 @@ gdm_get_login_window_session_id (const char  *seat_id,
 
                 free (service_class);
 
-                res = sd_session_get_state (sessions[i], &state);
-                if (res < 0) {
+                ret = sd_session_get_state (sessions[i], &state);
+                if (ret < 0) {
                         if (res == -ENXIO)
                                 continue;
 
@@ -554,7 +477,6 @@ out:
 
 static gboolean
 goto_login_session (GDBusConnection  *connection,
-                    GCancellable     *cancellable,
                     GError          **error)
 {
         gboolean        ret;
@@ -592,7 +514,7 @@ goto_login_session (GDBusConnection  *connection,
 
         res = gdm_get_login_window_session_id (seat_id, &session_id);
         if (res && session_id != NULL) {
-                res = gdm_activate_session_by_id (connection, cancellable, seat_id, session_id);
+                res = gdm_activate_session_by_id (connection, seat_id, session_id);
 
                 if (res) {
                         ret = TRUE;
@@ -600,7 +522,7 @@ goto_login_session (GDBusConnection  *connection,
         }
 
         if (! ret && g_strcmp0 (seat_id, "seat0") == 0) {
-                res = create_transient_display (connection, cancellable, error);
+                res = create_transient_display (connection, error);
                 if (res) {
                         ret = TRUE;
                 }
@@ -613,20 +535,20 @@ goto_login_session (GDBusConnection  *connection,
 }
 
 gboolean
-gdm_goto_login_session (GCancellable *cancellable,
-                        GError      **error)
+gdm_goto_login_session (GError **error)
 {
-        g_autoptr(GDBusConnection) connection = NULL;
-        g_autoptr(GError) local_error = NULL;
+        GError *local_error;
+        GDBusConnection *connection;
 
-        connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM, cancellable, &local_error);
+        local_error = NULL;
+        connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &local_error);
         if (connection == NULL) {
                 g_debug ("Failed to connect to the D-Bus daemon: %s", local_error->message);
-                g_propagate_error (error, g_steal_pointer (&local_error));
+                g_propagate_error (error, local_error);
                 return FALSE;
         }
 
-        return goto_login_session (connection, cancellable, error);
+        return goto_login_session (connection, error);
 }
 
 static void
@@ -650,7 +572,7 @@ gdm_get_script_environment (const char *username,
         GHashTable    *hash;
         struct passwd *pwent;
 
-        env = g_ptr_array_new_with_free_func (g_free);
+        env = g_ptr_array_new ();
 
         /* create a hash table of current environment, then update keys has necessary */
         hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
@@ -796,6 +718,7 @@ gdm_run_script (const char *dir,
                             &status,
                             &error);
 
+        g_ptr_array_foreach (env, (GFunc)g_free, NULL);
         g_ptr_array_free (env, TRUE);
         g_strfreev (argv);
 
@@ -823,14 +746,10 @@ gdm_shell_var_is_valid_char (gchar c, gboolean first)
                 g_ascii_isalpha (c);
 }
 
-/*
- * This expands a string somewhat similar to how a shell would do it
- * if it was enclosed inside double quotes.  It handles variable
- * expansion like $FOO and ${FOO}, single-char escapes using \, and
- * non-escaped # at the begining of a word is taken as a comment and ignored
-
- * The caller must free the returned string.
- */
+/* This expands a string somewhat similar to how a shell would do it
+   if it was enclosed inside double quotes.  It handles variable
+   expansion like $FOO and ${FOO}, single-char escapes using \, and
+   non-escaped # at the begining of a word is taken as a comment and ignored */
 char *
 gdm_shell_expand (const char *str,
                   GdmExpandVarFunc expand_var_func,
@@ -903,7 +822,7 @@ gdm_shell_expand (const char *str,
                         at_new_word = g_ascii_isspace (c);
                 }
         }
-        return g_string_free_and_steal (s);
+        return g_string_free (s, FALSE);
 }
 
 static gboolean
