@@ -53,9 +53,7 @@
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 
-#ifdef ENABLE_X11_SUPPORT
 #include <X11/Xlib.h> /* for Display */
-#endif
 
 #include "gdm-common.h"
 #include "gdm-settings-direct.h"
@@ -277,8 +275,7 @@ gdm_server_resolve_command_line (GdmServer  *server,
 
         gdm_server_init_command (server);
 
-        if (!g_shell_parse_argv (server->command, &argc, &argv, NULL))
-                return FALSE;
+        g_shell_parse_argv (server->command, &argc, &argv, NULL);
 
         for (len = 0; argv != NULL && argv[len] != NULL; len++) {
                 char *arg = argv[len];
@@ -431,9 +428,15 @@ gdm_server_setup_journal_fds (GdmServer *server)
 #ifdef ENABLE_SYSTEMD_JOURNAL
     if (sd_booted () > 0) {
         int out, err;
-        g_autofree char *identifier = NULL;
+        const char *prefix = "gdm-Xorg-";
+        char *identifier;
+        gsize size;
 
-        identifier = g_strdup_printf("gdm-Xorg-%s", server->display_name);
+        size = strlen (prefix) + strlen (server->display_name) + 1;
+        identifier = g_alloca (size);
+        strcpy (identifier, prefix);
+        strcat (identifier, server->display_name);
+        identifier[size - 1] = '\0';
 
         out = sd_journal_stream_fd (identifier, LOG_INFO, FALSE);
         if (out < 0)
@@ -673,13 +676,10 @@ gdm_server_spawn (GdmServer    *server,
         /* Figure out the server command */
         argv = NULL;
         argc = 0;
-
-        if (!gdm_server_resolve_command_line (server,
-                                              vtarg,
-                                              &argc,
-                                              &argv)) {
-                return FALSE;
-        }
+        gdm_server_resolve_command_line (server,
+                                         vtarg,
+                                         &argc,
+                                         &argv);
 
         if (server->session_args) {
                 server_add_xserver_args (server, &argc, &argv);
@@ -752,8 +752,6 @@ gdm_server_start (GdmServer *server)
         GError *local_error = NULL;
         GError **error = &local_error;
 
-        g_return_val_if_fail (GDM_IS_SERVER (server), FALSE);
-
         /* Hardcode the VT for the initial X server, but nothing else */
         if (server->is_initial) {
                 vtarg = "vt" G_STRINGIFY (GDM_INITIAL_VT);
@@ -804,19 +802,21 @@ gdm_server_stop (GdmServer *server)
 {
         int res;
 
-        g_return_val_if_fail (GDM_IS_SERVER (server), FALSE);
-
         if (server->pid <= 1) {
                 return TRUE;
         }
 
         /* remove watch source before we can wait on child */
-        g_clear_handle_id (&server->child_watch_id, g_source_remove);
+        if (server->child_watch_id > 0) {
+                g_source_remove (server->child_watch_id);
+                server->child_watch_id = 0;
+        }
 
         g_debug ("GdmServer: Stopping server");
 
         res = gdm_signal_pid (server->pid, SIGTERM);
-        if (res >= 0) {
+        if (res < 0) {
+        } else {
                 server_died (server);
         }
 
